==> qt4-x11_4.1.2.orig.tar.gz: qt-x11-opensource-src-4.1.2/tools/designer/src/lib/shared/newactiondialog_p.h <==
/****************************************************************************
**
** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
**
** This file is part of the Qt Designer of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#ifndef NEWACTIONDIALOG_P_H
#define NEWACTIONDIALOG_P_H

#include "ui_newactiondialog.h"

namespace qdesigner_internal {

class ActionEditor;

class NewActionDialog: public QDialog
{
    Q_OBJECT
public:
    NewActionDialog(ActionEditor *parent);
    virtual ~NewActionDialog();

    QString actionText() const;
    QString actionName() const;
    QIcon actionIcon() const;

    void setActionData(const QString &text, const QString &name, const QIcon &icon);

private slots:
    void accept();
    void on_editActionText_textEdited(const QString &text);
    void on_editObjectName_textEdited(const QString &text);
    void on_iconButton_clicked();
    void on_removeIconButton_clicked();

private:
    ActionEditor *m_actionEditor;
    Ui::NewActionDialog ui;
    bool m_auto_update_object_name;

    void updateButtons();
};

} // namespace qdesigner_internal

#endif // NEWACTIONDIALOG_P_H

==> qt4-x11_4.2.0.orig.tar.gz: qt-x11-opensource-src-4.2.0/tools/designer/src/lib/shared/newactiondialog_p.h <==
/****************************************************************************
**
** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
**
** This file is part of the Qt Designer of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#ifndef NEWACTIONDIALOG_P_H
#define NEWACTIONDIALOG_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "ui_newactiondialog.h"

namespace qdesigner_internal {

class ActionEditor;

class NewActionDialog: public QDialog
{
    Q_OBJECT
public:
    NewActionDialog(ActionEditor *parent);
    virtual ~NewActionDialog();

    QString actionText() const;
    QString actionName() const;
    QIcon actionIcon() const;

    void setActionData(const QString &text, const QString &name, const QIcon &icon);

private slots:
    void accept();
    void on_editActionText_textEdited(const QString &text);
    void on_editObjectName_textEdited(const QString &text);
    void on_iconButton_clicked();
    void on_removeIconButton_clicked();

private:
    ActionEditor *m_actionEditor;
    Ui::NewActionDialog ui;
    bool m_auto_update_object_name;

    void updateButtons();
};

} // namespace qdesigner_internal

#endif // NEWACTIONDIALOG_P_H
